create-db-cluster
Description
Creates a new Amazon Aurora DB cluster or Multi-AZ DB cluster.
If you create an Aurora DB cluster, the request creates an empty cluster. You must explicitly create the writer instance for your DB cluster using the CreateDBInstance operation. If you create a Multi-AZ DB cluster, the request creates a writer and two reader DB instances for you, each in a different Availability Zone.
You can use the ReplicationSourceIdentifier parameter to create an Amazon Aurora DB cluster as a read replica of another DB cluster or Amazon RDS for MySQL or PostgreSQL DB instance. For more information about Amazon Aurora, see What is Amazon Aurora? in the Amazon Aurora User Guide .
You can also use the ReplicationSourceIdentifier parameter to create a Multi-AZ DB cluster read replica with an RDS for MySQL or PostgreSQL DB instance as the source. For more information about Multi-AZ DB clusters, see Multi-AZ DB cluster deployments in the Amazon RDS User Guide .
See also: AWS API Documentation
Synopsis
create-db-cluster
[--availability-zones <value>]
[--backup-retention-period <value>]
[--character-set-name <value>]
[--database-name <value>]
--db-cluster-identifier <value>
[--db-cluster-parameter-group-name <value>]
[--vpc-security-group-ids <value>]
[--db-subnet-group-name <value>]
--engine <value>
[--engine-version <value>]
[--port <value>]
[--master-username <value>]
[--master-user-password <value>]
[--option-group-name <value>]
[--preferred-backup-window <value>]
[--preferred-maintenance-window <value>]
[--replication-source-identifier <value>]
[--tags <value>]
[--storage-encrypted | --no-storage-encrypted]
[--kms-key-id <value>]
[--pre-signed-url <value>]
[--enable-iam-database-authentication | --no-enable-iam-database-authentication]
[--backtrack-window <value>]
[--enable-cloudwatch-logs-exports <value>]
[--engine-mode <value>]
[--scaling-configuration <value>]
[--rds-custom-cluster-configuration <value>]
[--deletion-protection | --no-deletion-protection]
[--global-cluster-identifier <value>]
[--enable-http-endpoint | --no-enable-http-endpoint]
[--copy-tags-to-snapshot | --no-copy-tags-to-snapshot]
[--domain <value>]
[--domain-iam-role-name <value>]
[--enable-global-write-forwarding | --no-enable-global-write-forwarding]
[--db-cluster-instance-class <value>]
[--allocated-storage <value>]
[--storage-type <value>]
[--iops <value>]
[--publicly-accessible | --no-publicly-accessible]
[--auto-minor-version-upgrade | --no-auto-minor-version-upgrade]
[--monitoring-interval <value>]
[--monitoring-role-arn <value>]
[--database-insights-mode <value>]
[--enable-performance-insights | --no-enable-performance-insights]
[--performance-insights-kms-key-id <value>]
[--performance-insights-retention-period <value>]
[--enable-limitless-database | --no-enable-limitless-database]
[--serverless-v2-scaling-configuration <value>]
[--network-type <value>]
[--cluster-scalability-type <value>]
[--db-system-id <value>]
[--manage-master-user-password | --no-manage-master-user-password]
[--master-user-secret-kms-key-id <value>]
[--enable-local-write-forwarding | --no-enable-local-write-forwarding]
[--ca-certificate-identifier <value>]
[--engine-lifecycle-support <value>]
[--source-region <value>]
[--cli-input-json | --cli-input-yaml]
[--generate-cli-skeleton <value>]
[--debug]
[--endpoint-url <value>]
[--no-verify-ssl]
[--no-paginate]
[--output <value>]
[--query <value>]
[--profile <value>]
[--region <value>]
[--version <value>]
[--color <value>]
[--no-sign-request]
[--ca-bundle <value>]
[--cli-read-timeout <value>]
[--cli-connect-timeout <value>]
[--cli-binary-format <value>]
[--no-cli-pager]
[--cli-auto-prompt]
[--no-cli-auto-prompt]
Options
--availability-zones (list)
A list of Availability Zones (AZs) where you specifically want to create DB instances in the DB cluster.
For information on AZs, see Availability Zones in the Amazon Aurora User Guide .
Valid for Cluster Type: Aurora DB clusters only
Constraints:
- Can’t specify more than three AZs.
(string)
Syntax:
"string" "string" ...
--backup-retention-period (integer)
The number of days for which automated backups are retained.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Default: 1
Constraints:
- Must be a value from 1 to 35.
--character-set-name (string)
The name of the character set (CharacterSet ) to associate the DB cluster with.
Valid for Cluster Type: Aurora DB clusters only
--database-name (string)
The name for your database of up to 64 alphanumeric characters. A database named postgres is always created. If this parameter is specified, an additional database with this name is created.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
--db-cluster-identifier (string)
The identifier for this DB cluster. This parameter is stored as a lowercase string.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Constraints:
- Must contain from 1 to 63 (for Aurora DB clusters) or 1 to 52 (for Multi-AZ DB clusters) letters, numbers, or hyphens.
- First character must be a letter.
- Can’t end with a hyphen or contain two consecutive hyphens.
Example: my-cluster1
--db-cluster-parameter-group-name (string)
The name of the DB cluster parameter group to associate with this DB cluster. If you don’t specify a value, then the default DB cluster parameter group for the specified DB engine and version is used.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Constraints:
- If supplied, must match the name of an existing DB cluster parameter group.
--vpc-security-group-ids (list)
A list of EC2 VPC security groups to associate with this DB cluster.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
(string)
Syntax:
"string" "string" ...
--db-subnet-group-name (string)
A DB subnet group to associate with this DB cluster.
This setting is required to create a Multi-AZ DB cluster.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Constraints:
- Must match the name of an existing DB subnet group.
Example: mydbsubnetgroup
--engine (string)
The database engine to use for this DB cluster.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Valid Values:
aurora-mysqlaurora-postgresqlmysqlpostgres-
neptune- For information about using Amazon Neptune, see the ` Amazon Neptune User Guide https://docs.aws.amazon.com/neptune/latest/userguide/intro.html`__ .
--engine-version (string)
The version number of the database engine to use.
To list all of the available engine versions for Aurora MySQL version 2 (5.7-compatible) and version 3 (MySQL 8.0-compatible), use the following command:
aws rds describe-db-engine-versions --engine aurora-mysql --query "DBEngineVersions[].EngineVersion"You can supply either 5.7 or 8.0 to use the default engine version for Aurora MySQL version 2 or version 3, respectively.
To list all of the available engine versions for Aurora PostgreSQL, use the following command:
aws rds describe-db-engine-versions --engine aurora-postgresql --query "DBEngineVersions[].EngineVersion"To list all of the available engine versions for RDS for MySQL, use the following command:
aws rds describe-db-engine-versions --engine mysql --query "DBEngineVersions[].EngineVersion"To list all of the available engine versions for RDS for PostgreSQL, use the following command:
aws rds describe-db-engine-versions --engine postgres --query "DBEngineVersions[].EngineVersion"For information about a specific engine, see the following topics:
- Aurora MySQL - see Database engine updates for Amazon Aurora MySQL in the Amazon Aurora User Guide .
- Aurora PostgreSQL - see Amazon Aurora PostgreSQL releases and engine versions in the Amazon Aurora User Guide .
- RDS for MySQL - see Amazon RDS for MySQL in the Amazon RDS User Guide .
- RDS for PostgreSQL - see Amazon RDS for PostgreSQL in the Amazon RDS User Guide .
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
--port (integer)
The port number on which the instances in the DB cluster accept connections.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Valid Values: 1150-65535
Default:
- RDS for MySQL and Aurora MySQL -
3306 - RDS for PostgreSQL and Aurora PostgreSQL -
5432
--master-username (string)
The name of the master user for the DB cluster.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Constraints:
- Must be 1 to 16 letters or numbers.
- First character must be a letter.
- Can’t be a reserved word for the chosen database engine.
--master-user-password (string)
The password for the master database user.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Constraints:
- Must contain from 8 to 41 characters.
- Can contain any printable ASCII character except “/”, “””, or “@”.
- Can’t be specified if
ManageMasterUserPasswordis turned on.
--option-group-name (string)
The option group to associate the DB cluster with.
DB clusters are associated with a default option group that can’t be modified.
--preferred-backup-window (string)
The daily time range during which automated backups are created if automated backups are enabled using the BackupRetentionPeriod parameter.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
The default is a 30-minute window selected at random from an 8-hour block of time for each Amazon Web Services Region. To view the time blocks available, see Backup window in the Amazon Aurora User Guide .
Constraints:
- Must be in the format
hh24:mi-hh24:mi. - Must be in Universal Coordinated Time (UTC).
- Must not conflict with the preferred maintenance window.
- Must be at least 30 minutes.
--preferred-maintenance-window (string)
The weekly time range during which system maintenance can occur.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
The default is a 30-minute window selected at random from an 8-hour block of time for each Amazon Web Services Region, occurring on a random day of the week. To see the time blocks available, see Adjusting the Preferred DB Cluster Maintenance Window in the Amazon Aurora User Guide .
Constraints:
- Must be in the format
ddd:hh24:mi-ddd:hh24:mi. - Days must be one of
Mon | Tue | Wed | Thu | Fri | Sat | Sun. - Must be in Universal Coordinated Time (UTC).
- Must be at least 30 minutes.
--replication-source-identifier (string)
The Amazon Resource Name (ARN) of the source DB instance or DB cluster if this DB cluster is created as a read replica.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
--tags (list)
Tags to assign to the DB cluster.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
(structure)
Metadata assigned to an Amazon RDS resource consisting of a key-value pair.
For more information, see Tagging Amazon RDS resources in the Amazon RDS User Guide or Tagging Amazon Aurora and Amazon RDS resources in the Amazon Aurora User Guide .
Key -> (string)
aws: or rds: . The string can only contain only the set of Unicode letters, digits, white-space, ‘_’, ‘.’, ‘:’, ‘/’, ‘=’, ‘+’, ‘-’, ‘@’ (Java regex: “^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$”).Value -> (string)
aws: or rds: . The string can only contain only the set of Unicode letters, digits, white-space, ‘_’, ‘.’, ‘:’, ‘/’, ‘=’, ‘+’, ‘-’, ‘@’ (Java regex: “^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$”).Shorthand Syntax:
Key=string,Value=string ...
JSON Syntax:
[
{
"Key": "string",
"Value": "string"
}
...
]
--storage-encrypted | --no-storage-encrypted (boolean)
Specifies whether the DB cluster is encrypted.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
--kms-key-id (string)
The Amazon Web Services KMS key identifier for an encrypted DB cluster.
The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key. To use a KMS key in a different Amazon Web Services account, specify the key ARN or alias ARN.
When a KMS key isn’t specified in KmsKeyId :
- If
ReplicationSourceIdentifieridentifies an encrypted source, then Amazon RDS uses the KMS key used to encrypt the source. Otherwise, Amazon RDS uses your default KMS key. - If the
StorageEncryptedparameter is enabled andReplicationSourceIdentifierisn’t specified, then Amazon RDS uses your default KMS key.
There is a default KMS key for your Amazon Web Services account. Your Amazon Web Services account has a different default KMS key for each Amazon Web Services Region.
If you create a read replica of an encrypted DB cluster in another Amazon Web Services Region, make sure to set KmsKeyId to a KMS key identifier that is valid in the destination Amazon Web Services Region. This KMS key is used to encrypt the read replica in that Amazon Web Services Region.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
--pre-signed-url (string)
When you are replicating a DB cluster from one Amazon Web Services GovCloud (US) Region to another, an URL that contains a Signature Version 4 signed request for the CreateDBCluster operation to be called in the source Amazon Web Services Region where the DB cluster is replicated from. Specify PreSignedUrl only when you are performing cross-Region replication from an encrypted DB cluster.
The presigned URL must be a valid request for the CreateDBCluster API operation that can run in the source Amazon Web Services Region that contains the encrypted DB cluster to copy.
The presigned URL request must contain the following parameter values:
-
KmsKeyId- The KMS key identifier for the KMS key to use to encrypt the copy of the DB cluster in the destination Amazon Web Services Region. This should refer to the same KMS key for both theCreateDBClusteroperation that is called in the destination Amazon Web Services Region, and the operation contained in the presigned URL. -
DestinationRegion- The name of the Amazon Web Services Region that Aurora read replica will be created in. -
ReplicationSourceIdentifier- The DB cluster identifier for the encrypted DB cluster to be copied. This identifier must be in the Amazon Resource Name (ARN) format for the source Amazon Web Services Region. For example, if you are copying an encrypted DB cluster from the us-west-2 Amazon Web Services Region, then yourReplicationSourceIdentifierwould look like Example:arn:aws:rds:us-west-2:123456789012:cluster:aurora-cluster1.
To learn how to generate a Signature Version 4 signed request, see Authenticating Requests: Using Query Parameters (Amazon Web Services Signature Version 4) and Signature Version 4 Signing Process .
Note
If you are using an Amazon Web Services SDK tool or the CLI, you can specifySourceRegion (or --source-region for the CLI) instead of specifying PreSignedUrl manually. Specifying SourceRegion autogenerates a presigned URL that is a valid request for the operation that can run in the source Amazon Web Services Region.Valid for Cluster Type: Aurora DB clusters only
--enable-iam-database-authentication | --no-enable-iam-database-authentication (boolean)
Specifies whether to enable mapping of Amazon Web Services Identity and Access Management (IAM) accounts to database accounts. By default, mapping isn’t enabled.
For more information, see IAM Database Authentication in the Amazon Aurora User Guide or IAM database authentication for MariaDB, MySQL, and PostgreSQL in the Amazon RDS User Guide .
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
--backtrack-window (long)
The target backtrack window, in seconds. To disable backtracking, set this value to 0 .
Valid for Cluster Type: Aurora MySQL DB clusters only
Default: 0
Constraints:
- If specified, this value must be set to a number from 0 to 259,200 (72 hours).
--enable-cloudwatch-logs-exports (list)
The list of log types that need to be enabled for exporting to CloudWatch Logs.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
The following values are valid for each DB engine:
- Aurora MySQL -
audit | error | general | instance | slowquery | iam-db-auth-error - Aurora PostgreSQL -
instance | postgresql | iam-db-auth-error - RDS for MySQL -
error | general | slowquery | iam-db-auth-error - RDS for PostgreSQL -
postgresql | upgrade | iam-db-auth-error
For more information about exporting CloudWatch Logs for Amazon RDS, see Publishing Database Logs to Amazon CloudWatch Logs in the Amazon RDS User Guide .
For more information about exporting CloudWatch Logs for Amazon Aurora, see Publishing Database Logs to Amazon CloudWatch Logs in the Amazon Aurora User Guide .
(string)
Syntax:
"string" "string" ...
--engine-mode (string)
The DB engine mode of the DB cluster, either provisioned or serverless .
The serverless engine mode only applies for Aurora Serverless v1 DB clusters. Aurora Serverless v2 DB clusters use the provisioned engine mode.
For information about limitations and requirements for Serverless DB clusters, see the following sections in the Amazon Aurora User Guide :
- Limitations of Aurora Serverless v1
- Requirements for Aurora Serverless v2
Valid for Cluster Type: Aurora DB clusters only
--scaling-configuration (structure)
For DB clusters in serverless DB engine mode, the scaling properties of the DB cluster.
Valid for Cluster Type: Aurora DB clusters only
MinCapacity -> (integer)
The minimum capacity for an Aurora DB cluster in serverless DB engine mode.
For Aurora MySQL, valid capacity values are 1 , 2 , 4 , 8 , 16 , 32 , 64 , 128 , and 256 .
For Aurora PostgreSQL, valid capacity values are 2 , 4 , 8 , 16 , 32 , 64 , 192 , and 384 .
The minimum capacity must be less than or equal to the maximum capacity.
MaxCapacity -> (integer)
The maximum capacity for an Aurora DB cluster in serverless DB engine mode.
For Aurora MySQL, valid capacity values are 1 , 2 , 4 , 8 , 16 , 32 , 64 , 128 , and 256 .
For Aurora PostgreSQL, valid capacity values are 2 , 4 , 8 , 16 , 32 , 64 , 192 , and 384 .
The maximum capacity must be greater than or equal to the minimum capacity.
AutoPause -> (boolean)
Indicates whether to allow or disallow automatic pause for an Aurora DB cluster in serverless DB engine mode. A DB cluster can be paused only when it’s idle (it has no connections).
Note
If a DB cluster is paused for more than seven days, the DB cluster might be backed up with a snapshot. In this case, the DB cluster is restored when there is a request to connect to it.SecondsUntilAutoPause -> (integer)
The time, in seconds, before an Aurora DB cluster in serverless mode is paused.
Specify a value between 300 and 86,400 seconds.
TimeoutAction -> (string)
The action to take when the timeout is reached, either ForceApplyCapacityChange or RollbackCapacityChange .
ForceApplyCapacityChange sets the capacity to the specified value as soon as possible.
RollbackCapacityChange , the default, ignores the capacity change if a scaling point isn’t found in the timeout period.
Warning
If you specifyForceApplyCapacityChange , connections that prevent Aurora Serverless v1 from finding a scaling point might be dropped.For more information, see Autoscaling for Aurora Serverless v1 in the Amazon Aurora User Guide .
SecondsBeforeTimeout -> (integer)
The amount of time, in seconds, that Aurora Serverless v1 tries to find a scaling point to perform seamless scaling before enforcing the timeout action. The default is 300.
Specify a value between 60 and 600 seconds.
Shorthand Syntax:
MinCapacity=integer,MaxCapacity=integer,AutoPause=boolean,SecondsUntilAutoPause=integer,TimeoutAction=string,SecondsBeforeTimeout=integer
JSON Syntax:
{
"MinCapacity": integer,
"MaxCapacity": integer,
"AutoPause": true|false,
"SecondsUntilAutoPause": integer,
"TimeoutAction": "string",
"SecondsBeforeTimeout": integer
}
--rds-custom-cluster-configuration (structure)
Reserved for future use.
InterconnectSubnetId -> (string)
TransitGatewayMulticastDomainId -> (string)
ReplicaMode -> (string)
Shorthand Syntax:
InterconnectSubnetId=string,TransitGatewayMulticastDomainId=string,ReplicaMode=string
JSON Syntax:
{
"InterconnectSubnetId": "string",
"TransitGatewayMulticastDomainId": "string",
"ReplicaMode": "open-read-only"|"mounted"
}
--deletion-protection | --no-deletion-protection (boolean)
Specifies whether the DB cluster has deletion protection enabled. The database can’t be deleted when deletion protection is enabled. By default, deletion protection isn’t enabled.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
--global-cluster-identifier (string)
The global cluster ID of an Aurora cluster that becomes the primary cluster in the new global database cluster.
Valid for Cluster Type: Aurora DB clusters only
--enable-http-endpoint | --no-enable-http-endpoint (boolean)
Specifies whether to enable the HTTP endpoint for the DB cluster. By default, the HTTP endpoint isn’t enabled.
When enabled, the HTTP endpoint provides a connectionless web service API (RDS Data API) for running SQL queries on the DB cluster. You can also query your database from inside the RDS console with the RDS query editor.
For more information, see Using RDS Data API in the Amazon Aurora User Guide .
Valid for Cluster Type: Aurora DB clusters only
--copy-tags-to-snapshot | --no-copy-tags-to-snapshot (boolean)
Specifies whether to copy all tags from the DB cluster to snapshots of the DB cluster. The default is not to copy them.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
--domain (string)
The Active Directory directory ID to create the DB cluster in.
For Amazon Aurora DB clusters, Amazon RDS can use Kerberos authentication to authenticate users that connect to the DB cluster.
For more information, see Kerberos authentication in the Amazon Aurora User Guide .
Valid for Cluster Type: Aurora DB clusters only
--domain-iam-role-name (string)
The name of the IAM role to use when making API calls to the Directory Service.
Valid for Cluster Type: Aurora DB clusters only
--enable-global-write-forwarding | --no-enable-global-write-forwarding (boolean)
Specifies whether to enable this DB cluster to forward write operations to the primary cluster of a global cluster (Aurora global database). By default, write operations are not allowed on Aurora DB clusters that are secondary clusters in an Aurora global database.
You can set this value only on Aurora DB clusters that are members of an Aurora global database. With this parameter enabled, a secondary cluster can forward writes to the current primary cluster, and the resulting changes are replicated back to this cluster. For the primary DB cluster of an Aurora global database, this value is used immediately if the primary is demoted by a global cluster API operation, but it does nothing until then.
Valid for Cluster Type: Aurora DB clusters only
--db-cluster-instance-class (string)
The compute and memory capacity of each DB instance in the Multi-AZ DB cluster, for example db.m6gd.xlarge . Not all DB instance classes are available in all Amazon Web Services Regions, or for all database engines.
For the full list of DB instance classes and availability for your engine, see DB instance class in the Amazon RDS User Guide .
This setting is required to create a Multi-AZ DB cluster.
Valid for Cluster Type: Multi-AZ DB clusters only
--allocated-storage (integer)
The amount of storage in gibibytes (GiB) to allocate to each DB instance in the Multi-AZ DB cluster.
Valid for Cluster Type: Multi-AZ DB clusters only
This setting is required to create a Multi-AZ DB cluster.
--storage-type (string)
The storage type to associate with the DB cluster.
For information on storage types for Aurora DB clusters, see Storage configurations for Amazon Aurora DB clusters . For information on storage types for Multi-AZ DB clusters, see Settings for creating Multi-AZ DB clusters .
This setting is required to create a Multi-AZ DB cluster.
When specified for a Multi-AZ DB cluster, a value for the Iops parameter is required.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Valid Values:
- Aurora DB clusters -
aurora | aurora-iopt1 - Multi-AZ DB clusters -
io1 | io2 | gp3
Default:
- Aurora DB clusters -
aurora - Multi-AZ DB clusters -
io1
Note
When you create an Aurora DB cluster with the storage type set toaurora-iopt1 , the storage type is returned in the response. The storage type isn’t returned when you set it to aurora .--iops (integer)
The amount of Provisioned IOPS (input/output operations per second) to be initially allocated for each DB instance in the Multi-AZ DB cluster.
For information about valid IOPS values, see Provisioned IOPS storage in the Amazon RDS User Guide .
This setting is required to create a Multi-AZ DB cluster.
Valid for Cluster Type: Multi-AZ DB clusters only
Constraints:
- Must be a multiple between .5 and 50 of the storage amount for the DB cluster.
--publicly-accessible | --no-publicly-accessible (boolean)
Specifies whether the DB cluster is publicly accessible.
When the DB cluster is publicly accessible and you connect from outside of the DB cluster’s virtual private cloud (VPC), its Domain Name System (DNS) endpoint resolves to the public IP address. When you connect from within the same VPC as the DB cluster, the endpoint resolves to the private IP address. Access to the DB cluster is ultimately controlled by the security group it uses. That public access isn’t permitted if the security group assigned to the DB cluster doesn’t permit it.
When the DB cluster isn’t publicly accessible, it is an internal DB cluster with a DNS name that resolves to a private IP address.
Valid for Cluster Type: Multi-AZ DB clusters only
Default: The default behavior varies depending on whether DBSubnetGroupName is specified.
If DBSubnetGroupName isn’t specified, and PubliclyAccessible isn’t specified, the following applies:
- If the default VPC in the target Region doesn’t have an internet gateway attached to it, the DB cluster is private.
- If the default VPC in the target Region has an internet gateway attached to it, the DB cluster is public.
If DBSubnetGroupName is specified, and PubliclyAccessible isn’t specified, the following applies:
- If the subnets are part of a VPC that doesn’t have an internet gateway attached to it, the DB cluster is private.
- If the subnets are part of a VPC that has an internet gateway attached to it, the DB cluster is public.
--auto-minor-version-upgrade | --no-auto-minor-version-upgrade (boolean)
Specifies whether minor engine upgrades are applied automatically to the DB cluster during the maintenance window. By default, minor engine upgrades are applied automatically.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB cluster.
For more information about automatic minor version upgrades, see Automatically upgrading the minor engine version .
--monitoring-interval (integer)
The interval, in seconds, between points when Enhanced Monitoring metrics are collected for the DB cluster. To turn off collecting Enhanced Monitoring metrics, specify 0 .
If MonitoringRoleArn is specified, also set MonitoringInterval to a value other than 0 .
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Valid Values: 0 | 1 | 5 | 10 | 15 | 30 | 60
Default: 0
--monitoring-role-arn (string)
The Amazon Resource Name (ARN) for the IAM role that permits RDS to send Enhanced Monitoring metrics to Amazon CloudWatch Logs. An example is arn:aws:iam:123456789012:role/emaccess . For information on creating a monitoring role, see Setting up and enabling Enhanced Monitoring in the Amazon RDS User Guide .
If MonitoringInterval is set to a value other than 0 , supply a MonitoringRoleArn value.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
--database-insights-mode (string)
The mode of Database Insights to enable for the DB cluster.
If you set this value to advanced , you must also set the PerformanceInsightsEnabled parameter to true and the PerformanceInsightsRetentionPeriod parameter to 465.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Possible values:
standardadvanced
--enable-performance-insights | --no-enable-performance-insights (boolean)
Specifies whether to turn on Performance Insights for the DB cluster.
For more information, see Using Amazon Performance Insights in the Amazon RDS User Guide .
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
--performance-insights-kms-key-id (string)
The Amazon Web Services KMS key identifier for encryption of Performance Insights data.
The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key.
If you don’t specify a value for PerformanceInsightsKMSKeyId , then Amazon RDS uses your default KMS key. There is a default KMS key for your Amazon Web Services account. Your Amazon Web Services account has a different default KMS key for each Amazon Web Services Region.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
--performance-insights-retention-period (integer)
The number of days to retain Performance Insights data.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Valid Values:
7-
month * 31, where month is a number of months from 1-23. Examples:
93(3 months * 31),341(11 months * 31),589(19 months * 31) 731
Default: 7 days
If you specify a retention period that isn’t valid, such as 94 , Amazon RDS issues an error.
--enable-limitless-database | --no-enable-limitless-database (boolean)
Specifies whether to enable Aurora Limitless Database. You must enable Aurora Limitless Database to create a DB shard group.
Valid for: Aurora DB clusters only
Note
This setting is no longer used. Instead use theClusterScalabilityType setting.--serverless-v2-scaling-configuration (structure)
Contains the scaling configuration of an Aurora Serverless v2 DB cluster.
For more information, see Using Amazon Aurora Serverless v2 in the Amazon Aurora User Guide .
MinCapacity -> (double)
MaxCapacity -> (double)
SecondsUntilAutoPause -> (integer)
Specifies the number of seconds an Aurora Serverless v2 DB instance must be idle before Aurora attempts to automatically pause it.
Specify a value between 300 seconds (five minutes) and 86,400 seconds (one day). The default is 300 seconds.
Shorthand Syntax:
MinCapacity=double,MaxCapacity=double,SecondsUntilAutoPause=integer
JSON Syntax:
{
"MinCapacity": double,
"MaxCapacity": double,
"SecondsUntilAutoPause": integer
}
--network-type (string)
The network type of the DB cluster.
The network type is determined by the DBSubnetGroup specified for the DB cluster. A DBSubnetGroup can support only the IPv4 protocol or the IPv4 and the IPv6 protocols (DUAL ).
For more information, see Working with a DB instance in a VPC in the Amazon Aurora User Guide.
Valid for Cluster Type: Aurora DB clusters only
Valid Values: IPV4 | DUAL
--cluster-scalability-type (string)
Specifies the scalability mode of the Aurora DB cluster. When set to limitless , the cluster operates as an Aurora Limitless Database. When set to standard (the default), the cluster uses normal DB instance creation.
Valid for: Aurora DB clusters only
Note
You can’t modify this setting after you create the DB cluster.Possible values:
standardlimitless
--db-system-id (string)
--manage-master-user-password | --no-manage-master-user-password (boolean)
Specifies whether to manage the master user password with Amazon Web Services Secrets Manager.
For more information, see Password management with Amazon Web Services Secrets Manager in the Amazon RDS User Guide and Password management with Amazon Web Services Secrets Manager in the Amazon Aurora User Guide.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Constraints:
- Can’t manage the master user password with Amazon Web Services Secrets Manager if
MasterUserPasswordis specified.
--master-user-secret-kms-key-id (string)
The Amazon Web Services KMS key identifier to encrypt a secret that is automatically generated and managed in Amazon Web Services Secrets Manager.
This setting is valid only if the master user password is managed by RDS in Amazon Web Services Secrets Manager for the DB cluster.
The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key. To use a KMS key in a different Amazon Web Services account, specify the key ARN or alias ARN.
If you don’t specify MasterUserSecretKmsKeyId , then the aws/secretsmanager KMS key is used to encrypt the secret. If the secret is in a different Amazon Web Services account, then you can’t use the aws/secretsmanager KMS key to encrypt the secret, and you must use a customer managed KMS key.
There is a default KMS key for your Amazon Web Services account. Your Amazon Web Services account has a different default KMS key for each Amazon Web Services Region.
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
--enable-local-write-forwarding | --no-enable-local-write-forwarding (boolean)
Specifies whether read replicas can forward write operations to the writer DB instance in the DB cluster. By default, write operations aren’t allowed on reader DB instances.
Valid for: Aurora DB clusters only
--ca-certificate-identifier (string)
The CA certificate identifier to use for the DB cluster’s server certificate.
For more information, see Using SSL/TLS to encrypt a connection to a DB instance in the Amazon RDS User Guide .
Valid for Cluster Type: Multi-AZ DB clusters
--engine-lifecycle-support (string)
The life cycle type for this DB cluster.
Note
By default, this value is set toopen-source-rds-extended-support , which enrolls your DB cluster into Amazon RDS Extended Support. At the end of standard support, you can avoid charges for Extended Support by setting the value to open-source-rds-extended-support-disabled . In this case, creating the DB cluster will fail if the DB major version is past its end of standard support date.You can use this setting to enroll your DB cluster into Amazon RDS Extended Support. With RDS Extended Support, you can run the selected major engine version on your DB cluster past the end of standard support for that engine version. For more information, see the following sections:
- Amazon Aurora - Amazon RDS Extended Support with Amazon Aurora in the Amazon Aurora User Guide
- Amazon RDS - Amazon RDS Extended Support with Amazon RDS in the Amazon RDS User Guide
Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters
Valid Values: open-source-rds-extended-support | open-source-rds-extended-support-disabled
Default: open-source-rds-extended-support
--source-region (string)
--cli-input-json | --cli-input-yaml (string) Reads arguments from the JSON string provided. The JSON string follows the format provided by --generate-cli-skeleton. If other arguments are provided on the command line, those values will override the JSON-provided values. It is not possible to pass arbitrary binary values using a JSON-provided value as the string will be taken literally. This may not be specified along with --cli-input-yaml.
--generate-cli-skeleton (string) Prints a JSON skeleton to standard output without sending an API request. If provided with no value or the value input, prints a sample input JSON that can be used as an argument for --cli-input-json. Similarly, if provided yaml-input it will print a sample input YAML that can be used with --cli-input-yaml. If provided with the value output, it validates the command inputs and returns a sample output JSON for that command. The generated JSON skeleton is not stable between versions of the AWS CLI and there are no backwards compatibility guarantees in the JSON skeleton generated.
Global Options
--debug (boolean)
Turn on debug logging.
--endpoint-url (string)
Override command’s default URL with the given URL.
--no-verify-ssl (boolean)
By default, the AWS CLI uses SSL when communicating with AWS services. For each SSL connection, the AWS CLI will verify SSL certificates. This option overrides the default behavior of verifying SSL certificates.
--no-paginate (boolean)
Disable automatic pagination. If automatic pagination is disabled, the AWS CLI will only make one call, for the first page of results.
--output (string)
The formatting style for command output.
- json
- text
- table
- yaml
- yaml-stream
--query (string)
A JMESPath query to use in filtering the response data.
--profile (string)
Use a specific profile from your credential file.
--region (string)
The region to use. Overrides config/env settings.
--version (string)
Display the version of this tool.
--color (string)
Turn on/off color output.
- on
- off
- auto
--no-sign-request (boolean)
Do not sign requests. Credentials will not be loaded if this argument is provided.
--ca-bundle (string)
The CA certificate bundle to use when verifying SSL certificates. Overrides config/env settings.
--cli-read-timeout (int)
The maximum socket read time in seconds. If the value is set to 0, the socket read will be blocking and not timeout. The default value is 60 seconds.
--cli-connect-timeout (int)
The maximum socket connect time in seconds. If the value is set to 0, the socket connect will be blocking and not timeout. The default value is 60 seconds.
--cli-binary-format (string)
The formatting style to be used for binary blobs. The default format is base64. The base64 format expects binary blobs to be provided as a base64 encoded string. The raw-in-base64-out format preserves compatibility with AWS CLI V1 behavior and binary values must be passed literally. When providing contents from a file that map to a binary blob fileb:// will always be treated as binary and use the file contents directly regardless of the cli-binary-format setting. When using file:// the file contents will need to properly formatted for the configured cli-binary-format.
- base64
- raw-in-base64-out
--no-cli-pager (boolean)
Disable cli pager for output.
--cli-auto-prompt (boolean)
Automatically prompt for CLI input parameters.
--no-cli-auto-prompt (boolean)
Disable automatically prompt for CLI input parameters.
Examples
Note
To use the following examples, you must have the AWS CLI installed and configured. See the Getting started guide in the AWS CLI User Guide for more information.
Unless otherwise stated, all examples have unix-like quotation rules. These examples will need to be adapted to your terminal’s quoting rules. See Using quotation marks with strings in the AWS CLI User Guide .
Example 1: To create a MySQL 5.7–compatible DB cluster
The following create-db-cluster example creates a MySQL 5.7-compatible DB cluster using the default engine version. Replace the sample password secret99 with a secure password. When you use the console to create a DB cluster, Amazon RDS automatically creates the writer DB instance for your DB cluster. However, when you use the AWS CLI to create a DB cluster, you must explicitly create the writer DB instance for your DB cluster using the create-db-instance AWS CLI command.
aws rds create-db-cluster \
--db-cluster-identifier sample-cluster \
--engine aurora-mysql \
--engine-version 5.7 \
--master-username admin \
--master-user-password secret99 \
--db-subnet-group-name default \
--vpc-security-group-ids sg-0b9130572daf3dc16
Output:
{
"DBCluster": {
"DBSubnetGroup": "default",
"VpcSecurityGroups": [
{
"VpcSecurityGroupId": "sg-0b9130572daf3dc16",
"Status": "active"
}
],
"AllocatedStorage": 1,
"AssociatedRoles": [],
"PreferredBackupWindow": "09:12-09:42",
"ClusterCreateTime": "2023-02-27T23:21:33.048Z",
"DeletionProtection": false,
"IAMDatabaseAuthenticationEnabled": false,
"ReadReplicaIdentifiers": [],
"EngineMode": "provisioned",
"Engine": "aurora-mysql",
"StorageEncrypted": false,
"MultiAZ": false,
"PreferredMaintenanceWindow": "mon:04:31-mon:05:01",
"HttpEndpointEnabled": false,
"BackupRetentionPeriod": 1,
"DbClusterResourceId": "cluster-ANPAJ4AE5446DAEXAMPLE",
"DBClusterIdentifier": "sample-cluster",
"AvailabilityZones": [
"us-east-1a",
"us-east-1b",
"us-east-1e"
],
"MasterUsername": "master",
"EngineVersion": "5.7.mysql_aurora.2.11.1",
"DBClusterArn": "arn:aws:rds:us-east-1:123456789012:cluster:sample-cluster",
"DBClusterMembers": [],
"Port": 3306,
"Status": "creating",
"Endpoint": "sample-cluster.cluster-cnpexample.us-east-1.rds.amazonaws.com",
"DBClusterParameterGroup": "default.aurora-mysql5.7",
"HostedZoneId": "Z2R2ITUGPM61AM",
"ReaderEndpoint": "sample-cluster.cluster-ro-cnpexample.us-east-1.rds.amazonaws.com",
"CopyTagsToSnapshot": false
}
}
Example 2: To create a PostgreSQL–compatible DB cluster
The following create-db-cluster example creates a PostgreSQL-compatible DB cluster using the default engine version. Replace the example password secret99 with a secure password. When you use the console to create a DB cluster, Amazon RDS automatically creates the writer DB instance for your DB cluster. However, when you use the AWS CLI to create a DB cluster, you must explicitly create the writer DB instance for your DB cluster using the create-db-instance AWS CLI command.
aws rds create-db-cluster \
--db-cluster-identifier sample-pg-cluster \
--engine aurora-postgresql \
--master-username master \
--master-user-password secret99 \
--db-subnet-group-name default \
--vpc-security-group-ids sg-0b9130572daf3dc16
Output:
{
"DBCluster": {
"Endpoint": "sample-pg-cluster.cluster-cnpexample.us-east-1.rds.amazonaws.com",
"HttpEndpointEnabled": false,
"DBClusterMembers": [],
"EngineMode": "provisioned",
"CopyTagsToSnapshot": false,
"HostedZoneId": "Z2R2ITUGPM61AM",
"IAMDatabaseAuthenticationEnabled": false,
"AllocatedStorage": 1,
"VpcSecurityGroups": [
{
"VpcSecurityGroupId": "sg-0b9130572daf3dc16",
"Status": "active"
}
],
"DeletionProtection": false,
"StorageEncrypted": false,
"BackupRetentionPeriod": 1,
"PreferredBackupWindow": "09:56-10:26",
"ClusterCreateTime": "2023-02-27T23:26:08.371Z",
"DBClusterParameterGroup": "default.aurora-postgresql13",
"EngineVersion": "13.7",
"Engine": "aurora-postgresql",
"Status": "creating",
"DBClusterIdentifier": "sample-pg-cluster",
"MultiAZ": false,
"Port": 5432,
"DBClusterArn": "arn:aws:rds:us-east-1:123456789012:cluster:sample-pg-cluster",
"AssociatedRoles": [],
"DbClusterResourceId": "cluster-ANPAJ4AE5446DAEXAMPLE",
"PreferredMaintenanceWindow": "wed:03:33-wed:04:03",
"ReaderEndpoint": "sample-pg-cluster.cluster-ro-cnpexample.us-east-1.rds.amazonaws.com",
"MasterUsername": "master",
"AvailabilityZones": [
"us-east-1a",
"us-east-1b",
"us-east-1c"
],
"ReadReplicaIdentifiers": [],
"DBSubnetGroup": "default"
}
}
For more information, see Creating an Amazon Aurora DB cluster in the Amazon Aurora User Guide.
Output
DBCluster -> (structure)
Contains the details of an Amazon Aurora DB cluster or Multi-AZ DB cluster.
For an Amazon Aurora DB cluster, this data type is used as a response element in the operations CreateDBCluster , DeleteDBCluster , DescribeDBClusters , FailoverDBCluster , ModifyDBCluster , PromoteReadReplicaDBCluster , RestoreDBClusterFromS3 , RestoreDBClusterFromSnapshot , RestoreDBClusterToPointInTime , StartDBCluster , and StopDBCluster .
For a Multi-AZ DB cluster, this data type is used as a response element in the operations CreateDBCluster , DeleteDBCluster , DescribeDBClusters , FailoverDBCluster , ModifyDBCluster , RebootDBCluster , RestoreDBClusterFromSnapshot , and RestoreDBClusterToPointInTime .
For more information on Amazon Aurora DB clusters, see What is Amazon Aurora? in the Amazon Aurora User Guide.
For more information on Multi-AZ DB clusters, see Multi-AZ deployments with two readable standby DB instances in the Amazon RDS User Guide.
AllocatedStorage -> (integer)
AllocatedStorage specifies the allocated storage size in gibibytes (GiB). For Aurora, AllocatedStorage can vary because Aurora DB cluster storage size adjusts as needed.AvailabilityZones -> (list)
The list of Availability Zones (AZs) where instances in the DB cluster can be created.
(string)
BackupRetentionPeriod -> (integer)
CharacterSetName -> (string)
DatabaseName -> (string)
DBClusterIdentifier -> (string)
DBClusterParameterGroup -> (string)
DBSubnetGroup -> (string)
Status -> (string)
AutomaticRestartTime -> (timestamp)
PercentProgress -> (string)
EarliestRestorableTime -> (timestamp)
Endpoint -> (string)
ReaderEndpoint -> (string)
The reader endpoint for the DB cluster. The reader endpoint for a DB cluster load-balances connections across the Aurora Replicas that are available in a DB cluster. As clients request new connections to the reader endpoint, Aurora distributes the connection requests among the Aurora Replicas in the DB cluster. This functionality can help balance your read workload across multiple Aurora Replicas in your DB cluster.
If a failover occurs, and the Aurora Replica that you are connected to is promoted to be the primary instance, your connection is dropped. To continue sending your read workload to other Aurora Replicas in the cluster, you can then reconnect to the reader endpoint.
CustomEndpoints -> (list)
The custom endpoints associated with the DB cluster.
(string)
MultiAZ -> (boolean)
Engine -> (string)
EngineVersion -> (string)
LatestRestorableTime -> (timestamp)
Port -> (integer)
MasterUsername -> (string)
DBClusterOptionGroupMemberships -> (list)
The list of option group memberships for this DB cluster.
(structure)
Contains status information for a DB cluster option group.
DBClusterOptionGroupName -> (string)
Status -> (string)
PreferredBackupWindow -> (string)
BackupRetentionPeriod .PreferredMaintenanceWindow -> (string)
ReplicationSourceIdentifier -> (string)
ReadReplicaIdentifiers -> (list)
Contains one or more identifiers of the read replicas associated with this DB cluster.
(string)
StatusInfos -> (list)
Reserved for future use.
(structure)
Reserved for future use.
StatusType -> (string)
Normal -> (boolean)
Status -> (string)
Message -> (string)
DBClusterMembers -> (list)
The list of DB instances that make up the DB cluster.
(structure)
Contains information about an instance that is part of a DB cluster.
DBInstanceIdentifier -> (string)
IsClusterWriter -> (boolean)
DBClusterParameterGroupStatus -> (string)
PromotionTier -> (integer)
VpcSecurityGroups -> (list)
The list of VPC security groups that the DB cluster belongs to.
(structure)
This data type is used as a response element for queries on VPC security group membership.
VpcSecurityGroupId -> (string)
Status -> (string)
The membership status of the VPC security group.
Currently, the only valid status is active .
HostedZoneId -> (string)
StorageEncrypted -> (boolean)
KmsKeyId -> (string)
If StorageEncrypted is enabled, the Amazon Web Services KMS key identifier for the encrypted DB cluster.
The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key.
DbClusterResourceId -> (string)
DBClusterArn -> (string)
AssociatedRoles -> (list)
A list of the Amazon Web Services Identity and Access Management (IAM) roles that are associated with the DB cluster. IAM roles that are associated with a DB cluster grant permission for the DB cluster to access other Amazon Web Services on your behalf.
(structure)
Describes an Amazon Web Services Identity and Access Management (IAM) role that is associated with a DB cluster.
RoleArn -> (string)
Status -> (string)
Describes the state of association between the IAM role and the DB cluster. The Status property returns one of the following values:
-
ACTIVE- the IAM role ARN is associated with the DB cluster and can be used to access other Amazon Web Services on your behalf. -
PENDING- the IAM role ARN is being associated with the DB cluster. -
INVALID- the IAM role ARN is associated with the DB cluster, but the DB cluster is unable to assume the IAM role in order to access other Amazon Web Services on your behalf.
FeatureName -> (string)
IAMDatabaseAuthenticationEnabled -> (boolean)
CloneGroupId -> (string)
The ID of the clone group with which the DB cluster is associated. For newly created clusters, the ID is typically null.
If you clone a DB cluster when the ID is null, the operation populates the ID value for the source cluster and the clone because both clusters become part of the same clone group. Even if you delete the clone cluster, the clone group ID remains for the lifetime of the source cluster to show that it was used in a cloning operation.
For PITR, the clone group ID is inherited from the source cluster. For snapshot restore operations, the clone group ID isn’t inherited from the source cluster.
ClusterCreateTime -> (timestamp)
EarliestBacktrackTime -> (timestamp)
BacktrackWindow -> (long)
0 , backtracking is disabled for the DB cluster. Otherwise, backtracking is enabled.BacktrackConsumedChangeRecords -> (long)
EnabledCloudwatchLogsExports -> (list)
A list of log types that this DB cluster is configured to export to CloudWatch Logs.
Log types vary by DB engine. For information about the log types for each DB engine, see Amazon RDS Database Log Files in the Amazon Aurora User Guide.
(string)
Capacity -> (integer)
The current capacity of an Aurora Serverless v1 DB cluster. The capacity is 0 (zero) when the cluster is paused.
For more information about Aurora Serverless v1, see Using Amazon Aurora Serverless v1 in the Amazon Aurora User Guide .
EngineMode -> (string)
The DB engine mode of the DB cluster, either provisioned or serverless .
For more information, see CreateDBCluster .
ScalingConfigurationInfo -> (structure)
The scaling configuration for an Aurora DB cluster in serverless DB engine mode.
For more information, see Using Amazon Aurora Serverless v1 in the Amazon Aurora User Guide .
MinCapacity -> (integer)
serverless DB engine mode.MaxCapacity -> (integer)
serverless DB engine mode.AutoPause -> (boolean)
Indicates whether automatic pause is allowed for the Aurora DB cluster in serverless DB engine mode.
When the value is set to false for an Aurora Serverless v1 DB cluster, the DB cluster automatically resumes.
SecondsUntilAutoPause -> (integer)
serverless mode is paused. A DB cluster can be paused only when it’s idle (it has no connections).TimeoutAction -> (string)
The action that occurs when Aurora times out while attempting to change the capacity of an Aurora Serverless v1 cluster. The value is either ForceApplyCapacityChange or RollbackCapacityChange .
ForceApplyCapacityChange , the default, sets the capacity to the specified value as soon as possible.
RollbackCapacityChange ignores the capacity change if a scaling point isn’t found in the timeout period.
SecondsBeforeTimeout -> (integer)
TimeoutAction setting.RdsCustomClusterConfiguration -> (structure)
Reserved for future use.
InterconnectSubnetId -> (string)
TransitGatewayMulticastDomainId -> (string)
ReplicaMode -> (string)
DeletionProtection -> (boolean)
HttpEndpointEnabled -> (boolean)
Indicates whether the HTTP endpoint is enabled for an Aurora DB cluster.
When enabled, the HTTP endpoint provides a connectionless web service API (RDS Data API) for running SQL queries on the DB cluster. You can also query your database from inside the RDS console with the RDS query editor.
For more information, see Using RDS Data API in the Amazon Aurora User Guide .
ActivityStreamMode -> (string)
ActivityStreamStatus -> (string)
ActivityStreamKmsKeyId -> (string)
The Amazon Web Services KMS key identifier used for encrypting messages in the database activity stream.
The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key.
ActivityStreamKinesisStreamName -> (string)
CopyTagsToSnapshot -> (boolean)
CrossAccountClone -> (boolean)
DomainMemberships -> (list)
The Active Directory Domain membership records associated with the DB cluster.
(structure)
An Active Directory Domain membership record associated with the DB instance or cluster.
Domain -> (string)
Status -> (string)
joined , pending-join , failed , and so on.FQDN -> (string)
IAMRoleName -> (string)
OU -> (string)
AuthSecretArn -> (string)
DnsIps -> (list)
The IPv4 DNS IP addresses of the primary and secondary Active Directory domain controllers.
(string)
TagList -> (list)
A list of tags.
For more information, see Tagging Amazon RDS resources in the Amazon RDS User Guide or Tagging Amazon Aurora and Amazon RDS resources in the Amazon Aurora User Guide .
(structure)
Metadata assigned to an Amazon RDS resource consisting of a key-value pair.
For more information, see Tagging Amazon RDS resources in the Amazon RDS User Guide or Tagging Amazon Aurora and Amazon RDS resources in the Amazon Aurora User Guide .
Key -> (string)
aws: or rds: . The string can only contain only the set of Unicode letters, digits, white-space, ‘_’, ‘.’, ‘:’, ‘/’, ‘=’, ‘+’, ‘-’, ‘@’ (Java regex: “^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$”).Value -> (string)
aws: or rds: . The string can only contain only the set of Unicode letters, digits, white-space, ‘_’, ‘.’, ‘:’, ‘/’, ‘=’, ‘+’, ‘-’, ‘@’ (Java regex: “^([\p{L}\p{Z}\p{N}_.:/=+\-@]*)$”).GlobalWriteForwardingStatus -> (string)
GlobalWriteForwardingRequested -> (boolean)
GlobalWriteForwardingStatus to confirm that the request has completed before using the write forwarding feature for this cluster.PendingModifiedValues -> (structure)
Information about pending changes to the DB cluster. This information is returned only when there are pending changes. Specific changes are identified by subelements.
PendingCloudwatchLogsExports -> (structure)
A list of the log types whose configuration is still pending. In other words, these log types are in the process of being activated or deactivated.
LogTypesToEnable -> (list)
Log types that are in the process of being deactivated. After they are deactivated, these log types aren’t exported to CloudWatch Logs.
(string)
LogTypesToDisable -> (list)
Log types that are in the process of being enabled. After they are enabled, these log types are exported to CloudWatch Logs.
(string)
DBClusterIdentifier -> (string)
MasterUserPassword -> (string)
IAMDatabaseAuthenticationEnabled -> (boolean)
EngineVersion -> (string)
BackupRetentionPeriod -> (integer)
AllocatedStorage -> (integer)
AllocatedStorage always returns 1, because Aurora DB cluster storage size isn’t fixed, but instead automatically adjusts as needed.RdsCustomClusterConfiguration -> (structure)
Reserved for future use.
InterconnectSubnetId -> (string)
TransitGatewayMulticastDomainId -> (string)
ReplicaMode -> (string)
Iops -> (integer)
StorageType -> (string)
CertificateDetails -> (structure)
The details of the DB instance’s server certificate.
For more information, see Using SSL/TLS to encrypt a connection to a DB instance in the Amazon RDS User Guide and Using SSL/TLS to encrypt a connection to a DB cluster in the Amazon Aurora User Guide .
CAIdentifier -> (string)
ValidTill -> (timestamp)
DBClusterInstanceClass -> (string)
The name of the compute and memory capacity class of the DB instance.
This setting is only for non-Aurora Multi-AZ DB clusters.
StorageType -> (string)
Iops -> (integer)
The Provisioned IOPS (I/O operations per second) value.
This setting is only for non-Aurora Multi-AZ DB clusters.
PubliclyAccessible -> (boolean)
Indicates whether the DB cluster is publicly accessible.
When the DB cluster is publicly accessible and you connect from outside of the DB cluster’s virtual private cloud (VPC), its Domain Name System (DNS) endpoint resolves to the public IP address. When you connect from within the same VPC as the DB cluster, the endpoint resolves to the private IP address. Access to the DB cluster is ultimately controlled by the security group it uses. That public access isn’t permitted if the security group assigned to the DB cluster doesn’t permit it.
When the DB cluster isn’t publicly accessible, it is an internal DB cluster with a DNS name that resolves to a private IP address.
For more information, see CreateDBCluster .
This setting is only for non-Aurora Multi-AZ DB clusters.
AutoMinorVersionUpgrade -> (boolean)
Indicates whether minor version patches are applied automatically.
This setting is for Aurora DB clusters and Multi-AZ DB clusters.
For more information about automatic minor version upgrades, see Automatically upgrading the minor engine version .
MonitoringInterval -> (integer)
The interval, in seconds, between points when Enhanced Monitoring metrics are collected for the DB cluster.
This setting is only for -Aurora DB clusters and Multi-AZ DB clusters.
MonitoringRoleArn -> (string)
The ARN for the IAM role that permits RDS to send Enhanced Monitoring metrics to Amazon CloudWatch Logs.
This setting is only for Aurora DB clusters and Multi-AZ DB clusters.
DatabaseInsightsMode -> (string)
PerformanceInsightsEnabled -> (boolean)
Indicates whether Performance Insights is enabled for the DB cluster.
This setting is only for Aurora DB clusters and Multi-AZ DB clusters.
PerformanceInsightsKMSKeyId -> (string)
The Amazon Web Services KMS key identifier for encryption of Performance Insights data.
The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key.
This setting is only for Aurora DB clusters and Multi-AZ DB clusters.
PerformanceInsightsRetentionPeriod -> (integer)
The number of days to retain Performance Insights data.
This setting is only for Aurora DB clusters and Multi-AZ DB clusters.
Valid Values:
7-
month * 31, where month is a number of months from 1-23. Examples:
93(3 months * 31),341(11 months * 31),589(19 months * 31) 731
Default: 7 days
ServerlessV2ScalingConfiguration -> (structure)
The scaling configuration for an Aurora Serverless v2 DB cluster.
For more information, see Using Amazon Aurora Serverless v2 in the Amazon Aurora User Guide .
MinCapacity -> (double)
MaxCapacity -> (double)
SecondsUntilAutoPause -> (integer)
The number of seconds an Aurora Serverless v2 DB instance must be idle before Aurora attempts to automatically pause it. This property is only shown when the minimum capacity for the cluster is set to 0 ACUs. Changing the minimum capacity to a nonzero value removes this property. If you later change the minimum capacity back to 0 ACUs, this property is reset to its default value unless you specify it again.
This value ranges between 300 seconds (five minutes) and 86,400 seconds (one day). The default is 300 seconds.
NetworkType -> (string)
The network type of the DB instance.
The network type is determined by the DBSubnetGroup specified for the DB cluster. A DBSubnetGroup can support only the IPv4 protocol or the IPv4 and the IPv6 protocols (DUAL ).
For more information, see Working with a DB instance in a VPC in the Amazon Aurora User Guide.
This setting is only for Aurora DB clusters.
Valid Values: IPV4 | DUAL
DBSystemId -> (string)
MasterUserSecret -> (structure)
The secret managed by RDS in Amazon Web Services Secrets Manager for the master user password.
For more information, see Password management with Amazon Web Services Secrets Manager in the Amazon RDS User Guide and Password management with Amazon Web Services Secrets Manager in the Amazon Aurora User Guide.
SecretArn -> (string)
SecretStatus -> (string)
The status of the secret.
The possible status values include the following:
-
creating- The secret is being created. -
active- The secret is available for normal use and rotation. -
rotating- The secret is being rotated. -
impaired- The secret can be used to access database credentials, but it can’t be rotated. A secret might have this status if, for example, permissions are changed so that RDS can no longer access either the secret or the KMS key for the secret. When a secret has this status, you can correct the condition that caused the status. Alternatively, modify the DB instance to turn off automatic management of database credentials, and then modify the DB instance again to turn on automatic management of database credentials.
KmsKeyId -> (string)
IOOptimizedNextAllowedModificationTime -> (timestamp)
The next time you can modify the DB cluster to use the aurora-iopt1 storage type.
This setting is only for Aurora DB clusters.
LocalWriteForwardingStatus -> (string)
AwsBackupRecoveryPointArn -> (string)
LimitlessDatabase -> (structure)
The details for Aurora Limitless Database.
Status -> (string)
MinRequiredACU -> (double)
StorageThroughput -> (integer)
The storage throughput for the DB cluster. The throughput is automatically set based on the IOPS that you provision, and is not configurable.
This setting is only for non-Aurora Multi-AZ DB clusters.
ClusterScalabilityType -> (string)
limitless , the cluster operates as an Aurora Limitless Database. When set to standard (the default), the cluster uses normal DB instance creation.CertificateDetails -> (structure)
The details of the DB instance’s server certificate.
For more information, see Using SSL/TLS to encrypt a connection to a DB instance in the Amazon RDS User Guide and Using SSL/TLS to encrypt a connection to a DB cluster in the Amazon Aurora User Guide .
CAIdentifier -> (string)
ValidTill -> (timestamp)
EngineLifecycleSupport -> (string)
The lifecycle type for the DB cluster.
For more information, see CreateDBCluster.
© Copyright 2025, Amazon Web Services. Created using Sphinx.